pub struct Border<T, B, L, R> { /* private fields */ }Expand description
Border represents a border of a Cell.
top border
|
V
corner top left ------> +_______+ <---- corner top left
| |
left border ----------> | cell | <---- right border
| |
corner bottom right --> +_______+ <---- corner bottom right
^
|
bottom border
let table = Table::new(&data)
.with(Style::ascii())
.modify(Rows::single(0), Border::new().set_top('x'));Implementations
sourceimpl Border<On, On, On, On>
impl Border<On, On, On, On>
sourcepub const fn full(
top: char,
bottom: char,
left: char,
right: char,
top_left: char,
top_right: char,
bottom_left: char,
bottom_right: char,
) -> Self
pub const fn full( top: char, bottom: char, left: char, right: char, top_left: char, top_right: char, bottom_left: char, bottom_right: char, ) -> Self
This function constructs a cell borders with all sides set.
sourcepub const fn filled(c: char) -> Self
pub const fn filled(c: char) -> Self
This function constructs a cell borders with all sides’s char set to a given character.
It behaves like Border::full with the same character set to each side.
sourceimpl<T, B, L, R> Border<T, B, L, R>
impl<T, B, L, R> Border<T, B, L, R>
sourcepub const fn set_bottom(self, c: char) -> Border<T, On, L, R>
pub const fn set_bottom(self, c: char) -> Border<T, On, L, R>
Set a bottom border character.
sourcepub const fn into_inner(self) -> GridBorder<char>
pub const fn into_inner(self) -> GridBorder<char>
Converts a border into a general data structure.
sourceimpl<T, L, R> Border<T, On, L, R>
impl<T, L, R> Border<T, On, L, R>
sourcepub const fn get_bottom(&self) -> char
pub const fn get_bottom(&self) -> char
Get a bottom character.
sourceimpl<B, R> Border<On, B, On, R>
impl<B, R> Border<On, B, On, R>
sourcepub const fn set_corner_top_left(self, c: char) -> Self
pub const fn set_corner_top_left(self, c: char) -> Self
Set a top left intersection character.
sourcepub const fn get_corner_top_left(&self) -> char
pub const fn get_corner_top_left(&self) -> char
Get a top left intersection character.
sourceimpl<B, L> Border<On, B, L, On>
impl<B, L> Border<On, B, L, On>
sourcepub const fn set_corner_top_right(self, c: char) -> Self
pub const fn set_corner_top_right(self, c: char) -> Self
Set a top right intersection character.
sourcepub const fn get_corner_top_right(&self) -> char
pub const fn get_corner_top_right(&self) -> char
Get a top right intersection character.