Struct tabled::settings::style::BorderColor

source ·
pub struct BorderColor { /* private fields */ }
Available on crate feature std only.
Border represents a border color of a Cell.

                        top border
                            |
                            V
corner top left ------> +_______+  <---- corner top left
                        |       |
left border ----------> |  cell |  <---- right border
                        |       |
corner bottom right --> +_______+  <---- corner bottom right
                            ^
                            |
                       bottom border

Example

let table = Table::new(&data)
    .with(Style::ascii())
    .modify(Rows::single(0), BorderColor::new().top(Color::FG_RED));

Implementations

source

impl BorderColor

source

pub const fn new() -> Self

Creates an empty border.

source

pub const fn full( top: Color, bottom: Color, left: Color, right: Color, top_left: Color, top_right: Color, bottom_left: Color, bottom_right: Color, ) -> Self

This function constructs a cell borders with all sides set.

source

pub fn filled(c: Color) -> Self

This function constructs a cell borders with all sides’s char set to a given color. It behaves like BorderColor::full with the same color set to each side.

source

pub fn top(self, c: Color) -> Self

Set a top border color.

source

pub fn bottom(self, c: Color) -> Self

Set a bottom border color.

source

pub fn left(self, c: Color) -> Self

Set a left border color.

source

pub fn right(self, c: Color) -> Self

Set a right border color.

source

pub fn into_inner(self) -> GridBorder<Color>

Converts a border into a general data structure.

source

pub fn corner_top_left(self, c: Color) -> Self

Set a top left intersection color.

source

pub fn corner_top_right(self, c: Color) -> Self

Set a top right intersection color.

source

pub fn corner_bottom_left(self, c: Color) -> Self

Set a bottom left intersection color.

source

pub fn corner_bottom_right(self, c: Color) -> Self

Set a bottom right intersection color.